@@ -228,6 +228,8 @@ class MemoryGraphList(MutableSequence):
             list: List of Tensors.
         """
         if isinstance(items, dict):
+            if all([isinstance(value, dict) for value in items.values()]) and "name" not in items:
+                return {key: self._to_tensor(value, make_copy=make_copy) for key, value in items.items()}
             return self._to_tensor(items, make_copy=make_copy)
         elif isinstance(items, (tuple, list)):
             return [self._to_tensor(x, make_copy=make_copy) for x in items]
@@ -687,6 +689,7 @@ class MemoryGraphDataset(MemoryGraphList):
         The 'train' and 'test' properties must be set on the graph, and optionally an additional property
         for the validation split may be present. All of these properties may have either of the following
         values:
+
         - The property is a boolean integer value indicating whether the corresponding element of the
           dataset belongs to that part of the split (train / test)
         - The property is a list containing integer split indices, where each split index present within
