@@ -1,6 +1,6 @@
 import numpy as np
 
-from kgcnn.scaler.mol import ExtensiveMolecularScaler
+from kgcnn.data.transform.scaler.mol import ExtensiveMolecularScaler
 
 
 global_proton_dict = {'H': 1, 'He': 2, 'Li': 3, 'Be': 4, 'B': 5, 'C': 6, 'N': 7, 'O': 8, 'F': 9, 'Ne': 10, 'Na': 11,
